# !/usr/bin/env python
# -*- coding: utf-8 -*-
# @module: presentacion.py
# @author: Gustavo


''' ######################################################### '''
''' ##################  Paquete Vista Web  ################## '''
''' ######################################################### '''


class Formulario(object):
    '''
    Clase abstracta para la recogida de datos
    '''
    
    def __init__(self):
        self.tituloForm=""

    def getTituloForm (self):
        return self.tituloForm

    def setTituloForm (self, titulo):
        self.tituloForm=titulo

    def recogeDato(self, campo, form):
        '''
        Comprueba si se ha recibido un dato y recoge su valor
        '''
        if form.has_key(campo):
            return form[campo]
        else:
            return ""

class FormularioLista(Formulario):
    '''
    Clase para Formularios que listen objetos por páguinas
    '''
    
    def __init__(self):
        ''' Constructor '''
        Formulario.__init__(self)
        self.lista=[]
        self.pagina=1
        self.anterior=False
        self.siguiente=False
        self.objetosPagina=10
   
    def getLista(self):
        return self.lista

    def setLista(self, valores):
        self.lista=valores

    def numObjetos(self):
        return len(self.lista)

    def getPagina(self):
        return self.pagina

    def setPagina(self, pag):
        self.pagina=pag

    def siguientePagina(self):
        self.pagina=self.pagina+1
        self.habilitarAnterior()

    def anteriorPagina(self):
        self.pagina=self.pagina-1
        self.habilitarSiguiente()

    def getAnterior(self):
        return self.anterior

    def habilitarAnterior(self):
        self.anterior=True

    def deshabilitarAnterior(self):
        self.anterior=False

    def getSiguiente(self):
        return self.siguiente

    def habilitarSiguiente(self):
        self.siguiente=True

    def deshabilitarSiguiente(self):
        self.siguiente=False

    def getObjetosPagina(self):
        return self.objetosPagina

    def setObjetosPagina(self, objetosPag):
        self.objetosPagina=objetosPag
        
    def recogerPagina(self, form):
        self.pagina=int(self.recogeDato("pagina", form))
        self.objetosPagina=int(self.recogeDato("objetospagina", form))
        
        
class FormularioSelec(FormularioLista):
    '''
    Clase para seleccionar objetos por id
    '''
    
    def __init__(self):
        ''' Constructor '''
        FormularioLista.__init__(self)
        self.seleccionado=0
    
    def getSelecionado(self):
        return self.seleccionado
    
    def recogerElDato(self, form, nombre):
        if self.recogeDato(nombre, form)=="":
            self.seleccionado=0
        else:
            self.seleccionado=self.recogeDato(nombre, form)
        self.recogerPagina(form)

        
class FormularioSelecMulti(FormularioLista):
    '''
    Clase para seleccionar multiples objetos por id
    '''
    seleccionados=[]

    def __init__(self):
        ''' Constructor '''
        FormularioLista.__init__(self)
        seleccionados=[]
    
    def getSeleccionados(self):
        return self.seleccionados[:]
    
    def recogeLosDatos(self, form, numero, prefijo):
        ''' Recoge el numero de objetos indicado en la variable con el nombre proporcionado
            y los objetos seleccionados cuyo nombre empiece por el prefijo '''
        numObj=int(self.recogeDato(numero, form))
        i=0
        while (i<numObj):
            nomVal = prefijo+str(i)
            i=i+1
            if not (self.recogeDato(nomVal, form)==""):
                valor=self.recogeDato(nomVal, form)
                if valor.isdigit():
                    self.seleccionados.append(int(self.recogeDato(nomVal, form)))
                else:
                    self.seleccionados.append(self.recogeDato(nomVal, form))
        self.recogerPagina(form)


class FormularioProyecto(Formulario):
    '''
    Clase para la recogida de datos de un Proyecto
    '''
    def __init__(self):
        Formulario.__init__(self)
        self.nombre=""
        self.organizacion=""
        self.descripcion=""

    def getNombre(self):
        return self.nombre

    def getOrganizacion(self):
        return self.organizacion

    def getDescripcion(self):
        return self.descripcion

    def getDatos(self):
        return [self.nombre, self.organizacion, self.descripcion]

    def recogerDatos(self, form):
        ''' Recoge todos los datos de un proyecto '''
        self.nombre=self.recogeDato("nombre", form)
        self.organizacion=self.recogeDato("organizacion", form)
        self.descripcion=self.recogeDato("descripcion", form)

    def cogerDatos(self, valores):
        ''' Introduce los valores de proyecto en los campos del formulario '''
        self.nombre=valores[0]
        self.organizacion=valores[1]
        self.descripcion=valores[2]


class FormularioSelecProyecto(FormularioSelec):
    '''
    Clase para seleccionar un Proyecto
    '''
    
    def __init__(self):
        ''' Constructor '''
        FormularioSelec.__init__(self)
        
    def recogerDatos(self, form):
        self.recogerElDato(form, "idP")


class FormularioEliminarProyecto(FormularioSelecMulti):
    '''
    Clase para seleccionar un Proyecto
    '''
    def __init__(self):
        ''' Constructor '''
        FormularioSelecMulti.__init__(self)

        
    def recogerDatos(self, form):
        ''' Recoge el proyecto seleccionado '''
        self.recogeLosDatos(form, "numProy", "proy")


class FormularioLog(Formulario):
    '''
    Clase para la recogida de datos de un archivo LOG
    '''
    
    def __init__(self):
        ''' Constructor '''
        Formulario.__init__(self)
        self.archivo=file
        self.solapar=0
        self.tipos=Seleccionable()
            
    def getTipo(self):
        return self.tipos.getSeleccionado()

    def getArchivo(self):
        return self.archivo
    
    def getTipos(self):
        return self.tipos.getLista()

    def setTipos(self, valor):
        self.tipos=valor
    
    def getSolapar(self):
        return self.solapar

    def recogerDatos(self, form):
        ''' Recoge todos los datos del formulario '''
        self.tipos.setSeleccionado(int(self.recogeDato("tipo", form)))
        self.archivo=self.recogeDato("archivo", form)
        sol=self.recogeDato("solapar", form)
        if sol=='':
            self.solapar=0
        else:  
            self.solapar=int(sol)

class FormularioListaLog(FormularioLista):
    '''
    Clase para Formularios que listen Logs
    '''
    
    def __init__(self):
        ''' Constructor '''
        FormularioLista.__init__(self)
        
    def recogerDatos(self, form):
        ''' Recoge la página actual '''
        self.recogerPagina(form)


class FormularioEliminarLog(FormularioSelecMulti):
    '''
    Clase para eliminar un Log
    '''
    
    def __init__(self):
        ''' Constructor '''
        FormularioSelecMulti.__init__(self)

    def recogerDatos(self, form):
        ''' Recoge el proyecto seleccionado '''
        self.recogeLosDatos(form, "numLogs", "log")


class FormularioProgreso(Formulario):
    '''
    Clase para la visualizacion del progreso de un proceso
    '''
    
    def __init__(self):
        ''' Constructor '''
        Formulario.__init__(self)
        self.porcentaje=0
        
    def getPorcentaje(self):
        return self.porcentaje

    def setPorcentaje(self, porcen):
        self.porcentaje=porcen
        
    def recogerDatos(self, form):
        ''' Recoge los datos del formulario '''
        self.porcentaje=self.recogeDato("porcentaje", form)
        
        
class FormularioFechas(Formulario):
    '''
    Clase para la recogida de dos fechas y la presentación de una tabla
    '''
    
    def __init__(self):
        Formulario.__init__(self)
        self.fechaFin=''
        self.fechaIni=''
        self.fechaIniLimit=''
        self.fechaFinLimit=''
        self.fechasOpcion=0

    def getFechaIni(self):
        return self.fechaIni

    def setFechaIni(self, fecIni):
        self.fechaIni=fecIni
    
    def getFechaFin(self):
        return self.fechaFin

    def setFechaFin(self, fecFin):
        self.fechaFin=fecFin
    
    def getFechaIniLimit(self):
        return self.fechaIniLimit

    def setFechaIniLimit(self, fecsIni):
        self.fechaIniLimit=fecsIni
    
    def getFechaFinLimit(self):
        return self.fechaFinLimit

    def setFechaFinLimit(self, fecsFin):
        self.fechaFinLimit=fecsFin
        
    def getFechasOpcion(self):
        return self.fechasOpcion

    def recogerDatos(self, form):
        ''' Recoge los datos del formulario '''
        if self.recogeDato("fechasopcion", form)=="":
            self.fechasOpcion=0
        else:
            self.fechasOpcion=int(self.recogeDato("fechasopcion", form))
        if (self.fechasOpcion==1):
            self.fechaFin=self.recogeDato("fechaFin", form)
            self.fechaIni=self.recogeDato("fechaIni", form)
        else:
            self.fechaFin=self.recogeDato("fechaFinLimit", form)
            self.fechaIni=self.recogeDato("fechaIniLimit", form)

class FormularioTemResumen(FormularioFechas):
    '''
    Clase para la recogida de los datos de Resumen Temporal
    '''
    
    def __init__(self):
        FormularioFechas.__init__(self)
        self.tabla=[]
        self.archivoCSV=""
        self.agrupaciones=Seleccionable()
        self.agrupaciones.setLista(["Horas","Días de la Semana","Días del Mes","Meses","Años"])

    def getAgrupacion(self):
        return self.agrupaciones.getSeleccionado()
    
    def setAgrupacion(self, agrupacion):
        self.agrupaciones.setSeleccionado(agrupacion)
    
    def getAgrupaciones(self):
        return self.agrupaciones.getLista()
    
    def getTabla(self):
        return self.tabla

    def setTabla(self, tabla):
        self.tabla=tabla
    
    def getArchivoCSV(self):
        return self.archivoCSV

    def setArchivoCSV(self, archivo):
        self.archivoCSV=archivo
    
    def recogerDatos(self, form):
        ''' Recoge los datos del formulario '''
        if self.recogeDato("fechasopcion", form)=="":
            self.fechasOpcion=0
        else:
            self.fechasOpcion=int(self.recogeDato("fechasopcion", form))
        if (self.fechasOpcion==1):
            self.fechaFin=self.recogeDato("fechaFin", form)
            self.fechaIni=self.recogeDato("fechaIni", form)
        else:
            self.fechaFin=self.recogeDato("fechaFinLimit", form)
            self.fechaIni=self.recogeDato("fechaIniLimit", form)
        if self.recogeDato("agrupacion", form)=="":
            self.agrupaciones.setSeleccionado(0)
        else:
            self.agrupaciones.setSeleccionado(int(self.recogeDato("agrupacion", form)))


class FormularioGeoResumen(FormularioFechas):
    '''
    Clase para la recogida de los datos de Resumen Geografico
    '''
    
    def __init__(self):
        FormularioFechas.__init__(self)
        self.tabla=[]
        self.archivoCSV=""
        self.agrupacion=Seleccionable()
        self.agrupacion.setLista(["País","Región","Ciudad"])

    def getAgrupacion(self):
        return self.agrupacion.getSeleccionado()
    
    def setAgrupacion(self, agrupacion):
        self.agrupacion.setLista(agrupacion)
    
    def getAgrupaciones(self):
        return self.agrupacion.getLista()
    
    def getTabla(self):
        return self.tabla
    
    def setTabla(self, tabla):
        self.tabla=tabla
    
    def getArchivoCSV(self):
        return self.archivoCSV

    def setArchivoCSV(self, archivo):
        self.archivoCSV=archivo
    
    def recogerDatos(self, form):
        ''' Recoge los datos del formulario '''
        if self.recogeDato("fechasopcion", form)=="":
            self.fechasOpcion=0
        else:
            self.fechasOpcion=int(self.recogeDato("fechasopcion", form))
        if (self.fechasOpcion==1):
            self.fechaFin=self.recogeDato("fechaFin", form)
            self.fechaIni=self.recogeDato("fechaIni", form)
        else:
            self.fechaFin=self.recogeDato("fechaFinLimit", form)
            self.fechaIni=self.recogeDato("fechaIniLimit", form)
        if self.recogeDato("agrupacion", form)=="":
            self.agrupacion.setSeleccionado(0)
        else:
            self.agrupacion.setSeleccionado(int(self.recogeDato("agrupacion", form)))

                        
class FormularioNavInt(FormularioFechas):
    '''
    Clase para la recogida de los datos de Navegación Interna
    '''
    
    def __init__(self):
        FormularioFechas.__init__(self)
        self.tablaNavInt=TablaCabeceras()
        self.porcentaje=0.0
        self.archivoCSV=""
        self.archivoDOT=""
    
    def getTabla(self):
        return self.tablaNavInt

    def setTabla(self, tabla):
        self.tablaNavInt=tabla
    
    def getPorcentaje(self):
        return self.porcentaje

    def setPorcentaje(self, porcentaje):
        self.porcentaje=porcentaje
    
    def getArchivoCSV(self):
        return self.archivoCSV

    def setArchivoCSV(self, archivo):
        self.archivoCSV=archivo
    
    def getArchivoDOT(self):
        return self.archivoDOT

    def setArchivoDOT(self, archivo):
        self.archivoDOT=archivo
    
    def getCatProb(self, prob):
        if prob<=0.0005: resultado=0
        elif prob<=0.0050: resultado=1
        elif prob<=0.0500: resultado=2
        elif prob<=0.1000: resultado=3 
        elif prob<=0.2000: resultado=4
        elif prob<=0.4000: resultado=5
        elif prob<=0.6000: resultado=6
        elif prob<=0.8000: resultado=7
        elif prob<=0.9000: resultado=8
        else: resultado=9
        return resultado
    
class FormularioNavInOut(FormularioFechas):
    '''
    Clase para la recogida de los datos de Navegación Entradas Salidas
    '''
    
    def __init__(self):
        FormularioFechas.__init__(self)
        self.tablaEntradas=[]
        self.tablaSalidas=[]
        self.archivoEntradas=""
        self.archivoSalidas=""
    
    def getTablaEntradas(self):
        return self.tablaEntradas

    def setTablaEntradas(self, tabla):
        self.tablaEntradas=tabla
        
    def getTablaSalidas(self):
        return self.tablaSalidas

    def setTablaSalidas(self, tabla):
        self.tablaSalidas=tabla
    
    def getArchivoEntradas(self):
        return self.archivoEntradas

    def setArchivoEntradas(self, archivo):
        self.archivoEntradas=archivo
    
    def getArchivoSalidas(self):
        return self.archivoSalidas

    def setArchivoSalidas(self, archivo):
        self.archivoSalidas=archivo
        

class FormularioCargaDescriptiva(FormularioFechas):
    '''
    Clase para la recogida de los datos de Carga Descriptiva
    '''
    
    def __init__(self):
        FormularioFechas.__init__(self)
        self.tablaResumen=[]
        self.tablaGeneral=[]
        self.porcentaje=0.0
        self.archivoGeneral=""
        self.archivoResumen=""
        self.resumen=0
        self.opcion=0
        self.tipo=0
        self.ceros=0
        
    def getResumen(self):
        return self.resumen
    
    def getOpcion(self):
        return self.opcion
    
    def getTipo(self):
        return self.tipo
    
    def getCeros(self):
        return self.ceros
    
    def getTablaResumen(self):
        return self.tablaResumen

    def setTablaResumen(self, tabla):
        self.tablaResumen=tabla
    
    def getTablaGeneral(self):
        return self.tablaGeneral

    def setTablaGeneral(self, tabla):
        self.tablaGeneral=tabla 
        
    def getPorcentaje(self):
        return self.porcentaje

    def setPorcentaje(self, porcentaje):
        self.porcentaje=porcentaje
        
    def getArchivoGeneral(self):
        return self.archivoGeneral

    def setArchivoGeneral(self, archivo):
        self.archivoGeneral=archivo
    
    def getArchivoResumen(self):
        return self.archivoResumen

    def setArchivoResumen(self, archivo):
        self.archivoResumen=archivo
        
    def getNombreEstadistica(self):
        nombre=""
        if self.opcion==0:
            nombre="accesos "
        elif self.opcion==1:
            nombre="tamaños "
        else:
            nombre="tiempos "
        if self.ceros>0:
            if self.tipo==0:
                nombre=nombre+"máximos "
            else:
                nombre=nombre+"mínimos "
        if self.opcion>0:
            if self.ceros==0:
                nombre=nombre+"cero"
            elif self.ceros==1:
                nombre=nombre+"con ceros"
            else:
                nombre=nombre+"sin ceros"
        return nombre
        
    def recogerDatos(self, form):
        ''' Recoge los datos del formulario '''
        if self.recogeDato("fechasopcion", form)=="":
            self.fechasOpcion=0
        else:
            self.fechasOpcion=int(self.recogeDato("fechasopcion", form))
        if (self.fechasOpcion==1):
            self.fechaFin=self.recogeDato("fechaFin", form)
            self.fechaIni=self.recogeDato("fechaIni", form)
        else:
            self.fechaFin=self.recogeDato("fechaFinLimit", form)
            self.fechaIni=self.recogeDato("fechaIniLimit", form)
        resum=self.recogeDato("resumen", form)
        if resum=='':
            self.resumen=0
        else:  
            self.resumen=int(resum)
        if self.recogeDato("opcion", form)=="":
            self.opcion=0
        else:
            self.opcion=int(self.recogeDato("opcion", form))
        if self.recogeDato("tipo", form)=="":
            self.tipo=0
        else:
            self.tipo=int(self.recogeDato("tipo", form))
        if self.recogeDato("ceros", form)=="":
            self.ceros=0
        else:
            self.ceros=int(self.recogeDato("ceros", form))
            
            
class FormularioCargaModelo(FormularioFechas):
    '''
    Clase para la recogida de los datos de Modelo de Carga
    '''
    
    def __init__(self):
        FormularioFechas.__init__(self)
        self.tabla=[]
        self.archivoCSV=""
        self.metodo=0
        self.metrica=0
        self.criterio=0
        self.cerosTamano=0
        self.cerosTiempo=0
        self.metodos=["single","complete","average","weighted"]
        self.metricas=["euclidean","minkowski","cityblock"]
        self.criterios=["distance","maxclust","inconsistent"]
        self.muldistancia=0.5

    def getMetodo(self):
        return self.metodo
    
    def getMetodos(self):
        return self.metodos
    
    def getMetrica(self):
        return self.metrica
    
    def getMetricas(self):
        return self.metricas
    
    def getCriterio(self):
        return self.criterio
    
    def getCriterios(self):
        return self.criterios
    
    def getMulDistancia(self):
        return self.muldistancia
    
    def getCerosTamano(self):
        return self.cerosTamano
    
    def getCerosTiempo(self):
        return self.cerosTiempo
    
    def getTabla(self):
        return self.tabla

    def setTabla(self, tabla):
        self.tabla=tabla
    
    def getArchivoCSV(self):
        return self.archivoCSV

    def setArchivoCSV(self, archivo):
        self.archivoCSV=archivo
    
    def recogerDatos(self, form):
        ''' Recoge los datos del formulario '''
        if self.recogeDato("fechasopcion", form)=="":
            self.fechasOpcion=0
        else:
            self.fechasOpcion=int(self.recogeDato("fechasopcion", form))
        if (self.fechasOpcion==1):
            self.fechaFin=self.recogeDato("fechaFin", form)
            self.fechaIni=self.recogeDato("fechaIni", form)
        else:
            self.fechaFin=self.recogeDato("fechaFinLimit", form)
            self.fechaIni=self.recogeDato("fechaIniLimit", form)
        if self.recogeDato("metodo", form)=="":
            self.metodo=0
        else:
            self.metodo=int(self.recogeDato("metodo", form))
        if self.recogeDato("metrica", form)=="":
            self.metrica=0
        else:
            self.metrica=int(self.recogeDato("metrica", form))
        if self.recogeDato("criterio", form)=="":
            self.criterio=0
        else:
            self.criterio=int(self.recogeDato("criterio", form))
        if self.recogeDato("muldistancia", form)=="":
            self.muldistancia=0.5
        else:
            self.muldistancia=float(self.recogeDato("muldistancia", form))
        if self.recogeDato("cerosTamano", form)=="":
            self.cerosTamano=0
        else:
            self.cerosTamano=int(self.recogeDato("cerosTamano", form))
        if self.recogeDato("cerosTiempo", form)=="":
            self.cerosTiempo=0
        else:
            self.cerosTiempo=int(self.recogeDato("cerosTiempo", form))
        
        
''' ######################################################## '''
''' ###############  Paquete Modelo Entrada  ############### '''
''' ######################################################## '''

class Menu(object):
    '''
    Clase Menu
    '''
    
    def __init__(self):
        ''' Constructor '''
        self.acciones=[]

    def getAccion(self, indice):
        ''' Devuelve la acción que está en en numero indice del menu '''
        return self.acciones[indice]
    
    def getAcciones(self):
        ''' Devuelve un array con todas las acciones del menu '''
        return self.acciones

    def getNumAcciones(self):
        ''' Devuelve el número de acciones del menú '''
        return len(self.acciones)

    def insertarAccion(self, datos):
        ''' Inserta una accion en el menú.
            El parametro datos ha de ser una Acción '''
        self.acciones.append(datos)

    def borrarAcciones(self):
        ''' Borra el menú '''
        while 0 < self.getNumAcciones():
            a=self.acciones.pop()


class SubMenu(Menu):
    '''
    Clase para la representación de un menú de opciones
    '''
        
    def __init__(self):
        Menu.__init__(self)
        accionPrincipal=Accion()

    def getAccionPrincipal(self):
        return self.accionPrincipal
    
    def setAccionPrincipal(self, accion):
        self.accionPrincipal=accion
    
    def hayAccionPrincipal(self):
        return self.accionPrincipal.getId()<>0
    

class Accion(object):
    '''
    Clase Accion
    '''
    
    def __init__(self):
        ''' Constructor '''
        self.id=0
        self.nombre=""
        self.url=""
        self.icono=""
        
    def getId(self):
        ''' Devuelve el id de la acción '''
        return self.nombre

    def getNombre(self):
        ''' Devuelve el nombre de la acción '''
        return self.nombre

    def getUrl(self):
        ''' Devuelve la URL de la accion '''
        return self.url
    
    def getIcono(self):
        ''' Devuelve el icono de la accion '''
        return self.icono

    def setNombre(self, nombre):
        ''' El nombre toma como valor el pasado como parámetro '''
        self.nombre=nombre
        
    def setUrl(self, url):
        ''' El URL toma como valor el pasado como parámetro '''
        self.url=url
        
    def setIcono(self, icono):
        ''' El icono toma como valor el pasado como parámetro '''
        self.icono=icono

    def setDatos(self, valores):
        ''' Las propiedades de la accion toman como valor los datos del array pasado como parámetro '''
        self.id=valores[0]
        self.nombre=valores[1]
        self.url=valores[2]
        self.icono=valores[3]

        
class Funcion(Accion):

    def __init__(self):
        ''' Constructor '''
        Accion.__init__(self)
        self.seleccion=0
    
    def setDatos(self, valores):
        ''' Las propiedades de la funcion toman como valor los datos del array pasado como parámetro '''
        self.id=valores[0]
        self.nombre=valores[1]
        self.url=valores[2]
        self.icono=valores[3]
        self.seleccion=valores[4]


class Estadistica(Accion):
    '''
    Clase Estadistica
    '''
    
    def __init__(self):
        ''' Constructor '''
        Accion.__init__(self)
        self.tipo=0

    def setDatos(self, valores):
        ''' Las propiedades de la estadistica toman como valor los datos del array pasado como parámetro '''
        self.id=valores[0]
        self.nombre=valores[1]
        self.url=valores[2]
        self.icono=valores[3]
        self.tipo=valores[4]

        
class ListaPaginada(object):
    '''
    Clase Lista con páginas
    '''
    
    def __init__(self):
        self.lista=[]
        '''while 0 < len(self.lista):'''
        '''    a=self.lista.pop()'''
        self.objetospagina=10

    def getObjetosPagina(self):
        return self.objetospagina

    def setObjetosPagina(self, num):
        self.objetospagina=num
    
    def getLista(self):
        return self.lista

    def setLista(self, lis):
        self.lista=lis

    def getListaPagina(self, num_pagina):
        if num_pagina<=self.numPaginas() and num_pagina>0:
            inicio=(num_pagina-1)*self.objetospagina
            if (num_pagina*self.objetospagina)>((len(self.lista))-1):
                fin=len(self.lista)
            else:
                fin=num_pagina*self.objetospagina
        else:
            inicio=0
            fin=len(self.lista)
        return self.lista[inicio:fin]

    def numPaginas(self):
        retorno= (len(self.lista))/self.objetospagina
        if (len(self.lista)%self.objetospagina)>0:
            retorno=retorno+1
        return retorno
    
    def numObjetos(self):
        return len(self.lista)

    def vaciar(self):
        while 0 < len(self.lista):
            a=self.lista.pop()
        self.objetospagina=10


class Seleccionable(object):
    '''
    Clase Seleccionable
    '''
    
    def __init__(self):
        self.lista=[]
        self.seleccionado=0

    def getSeleccionado(self):
        return self.seleccionado

    def setSeleccionado(self, selec):
        self.seleccionado=selec
    
    def getLista(self):
        return self.lista

    def setLista(self, lis):
        self.lista=lis
        
    def insertar(self, objeto):
        self.lista.append(objeto)

    def numObjetos(self):
        return len(self.lista)

    def vaciar(self):
        while 0 < len(self.lista):
            a=self.lista.pop()
        self.seleccionado=0
 
        
class Tabla(object):
    '''
    Clase Tabla
    '''
    def __init__(self):
        self.tabla=[]

    def getTabla(self):
        return self.tabla[:]

    def setTabla(self, tabla):
        self.tabla=tabla
    
    def getElemento(self, coorver, coorhor):
        return self.tabla[coorver][coorhor]
    
    def setElemento(self, elemento, coorhor, coorver):
        self.tabla[coorhor][coorver]=elemento


class TablaCabeceras(Tabla):
    '''
    Clase Tabla con cabeceras
    '''
        
    def __init__(self):
        Tabla.__init__(self)
        self.primfilcab=[]
        self.primcolcab=[]

    def getPrimFilCab(self):
        return self.primfilcab[:]

    def setPrimFilCab(self, primfilcab):
        self.primfilcab=primfilcab
    
    def getPrimColCab(self):
        return self.primcolcab[:]

    def setPrimColCab(self, primcolcab):
        self.primcolcab=primcolcab
    
    def TieneFilCab(self):
        return len(self.primfilcab)==0
    
    def TieneColCab(self):
        return len(self.primcolcab)==0
